package # Hide from PAUSE
Upload::Digest::V::TT;

use strict;
use base qw< Catalyst::View::TT >;

=head1 NAME

Upload::Digest::V::TT - TT view for L<Upload::Digest>

=head1 DESCRIPTION

This is just a wrapper around L<Catalyst::View::TT>

=cut

1;
